@@ -36,3 +36,13 @@ LIB_EXPORT bool CC KProcMgrOnMainThread ( void )
 {
     return pthread_main_np () != 0;
 }
+
+uint32_t sys_GetPID ( void )
+{
+    return getpid ();
+}
+
+int sys_GetHostName ( char * buffer, size_t buffer_size )
+{
+    return gethostname( buffer, buffer_size );
+}
